.. Excel Modelling Helper documentation master file, created by
sphinx-quickstart on Wed Jun  7 15:07:55 2017.
You can adapt this file completely to your liking, but it should at least
contain the root `toctree` directive.

Welcome to Excel Modelling Helper's documentation!
==================================================

.. toctree::
:maxdepth: 2
       :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
